==> ifrit_3.0.0.orig.tar.gz: ifrit-3.0.0/core/ireducepolydatafilter.cpp <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#include "ireducepolydatafilter.h"


//
//  Templates
//
#include "igenericfiltertemplate.h"


iReducePolyDataFilter* iReducePolyDataFilter::New()
{
	return new iReducePolyDataFilter;
}
	

void iReducePolyDataFilter::ProduceOutput(vtkPolyData *input, vtkPolyData *output)
{
	if(input->GetPoints()==0 || input->GetPoints()->GetDataType()==VTK_FLOAT)
	{
		this->vtkDecimatePro::ExecuteData(output);
	}
	else
	{
		vtkWarningMacro("Cannot reduce polygonal data with double-valued coordinates due to VTK bug.");
		output->ShallowCopy(input);
	}
}

==> ifrit_3.2.0.orig.tar.gz: ifrit-3.2.0/core/ireducepolydatafilter.cpp <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#include "ireducepolydatafilter.h"


//
//  Templates
//
#include "igenericfiltertemplate.h"


iReducePolyDataFilter::iReducePolyDataFilter(iViewSubject *vo) : iGenericPolyDataToPolyDataFilter<vtkDecimatePro>(vo,1,true,false)
{
}
	

void iReducePolyDataFilter::ProduceOutput()
{
	vtkPolyData *input = vtkPolyData::SafeDownCast(this->GetInput());
	vtkPolyData *output = this->GetOutput();

	if(input->GetPoints()==0 || input->GetPoints()->GetDataType()==VTK_FLOAT)
	{
		this->ExecuteParent();
	}
	else
	{
		vtkWarningMacro("Cannot reduce polygonal data with double-valued coordinates due to a VTK bug.");
		output->ShallowCopy(input);
	}
}
